nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

OtpClkDiv

Struct OtpClkDiv 

#[repr(transparent)]
pub struct OtpClkDiv(pub u32);
OTP clock divider register

Tuple Fields

0: u32

Implementations

Source

impl OtpClkDiv

pub const fn div(&self) -> Div

Clock divider value by -1 encoding. It’s used to generate the clock to OTP memory (otp_clk) with apb_clk. The maximum otp_clk frequency is 120Mhz. 0: Divide by 1

pub const fn set_div(&mut self, val: Div)

Clock divider value by -1 encoding. It’s used to generate the clock to OTP memory (otp_clk) with apb_clk. The maximum otp_clk frequency is 120Mhz. 0: Divide by 1

pub const fn reset(&self) -> bool

Resets the divider counter. Can be used to make sure a new divider value is used right away rather than completing the previous count.

pub const fn set_reset(&mut self, val: bool)

Resets the divider counter. Can be used to make sure a new divider value is used right away rather than completing the previous count.

pub const fn halt(&self) -> bool

Halts the divider counter. The intent is to allow the divider’s clock source to be changed without the risk of a glitch at the output.

pub const fn set_halt(&mut self, val: bool)

Halts the divider counter. The intent is to allow the divider’s clock source to be changed without the risk of a glitch at the output.

pub const fn reqflag(&self) -> bool

Divider status flag. Set when a change is made to the divider value, cleared when the change is complete.

pub const fn set_reqflag(&mut self, val: bool)

Divider status flag. Set when a change is made to the divider value, cleared when the change is complete.