nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

OtpCrcValue

Struct OtpCrcValue 

#[repr(transparent)]
pub struct OtpCrcValue(pub u32);
CRC result register

Tuple Fields

0: u32

Implementations

Source

impl OtpCrcValue

pub const fn crc_value(&self) -> u32

The CRC result value. When it is locked, reading from it returns value 32hBADA_BADA

pub const fn set_crc_value(&mut self, val: u32)

The CRC result value. When it is locked, reading from it returns value 32hBADA_BADA