nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

OtpCtrl

Struct OtpCtrl 

#[repr(transparent)]
pub struct OtpCtrl(pub u32);
Control/address register

Tuple Fields

0: u32

Implementations

Source

impl OtpCtrl

pub const fn addr(&self) -> u16

OTP word address for read/programming

pub const fn set_addr(&mut self, val: u16)

OTP word address for read/programming

pub const fn reload_shadows(&self) -> bool

Set to force re-loading the shadow registers (HW/SW capability and LOCK). This operation will automatically set OTP_STATUS.BUSY. Once the shadow registers have been re-loaded, OTP_STATUS.BUSY and RELOAD_SHADOWS are automatically cleared by the controller

pub const fn set_reload_shadows(&mut self, val: bool)

Set to force re-loading the shadow registers (HW/SW capability and LOCK). This operation will automatically set OTP_STATUS.BUSY. Once the shadow registers have been re-loaded, OTP_STATUS.BUSY and RELOAD_SHADOWS are automatically cleared by the controller

pub const fn crc_test(&self) -> bool

Set to start CRC calculation. This operation will automatically set OTP_STATUS.BUSY. Once CRC is calculation done, OTP_STATUS.BUSY and CRC_TEST are automatically cleared by the controller

pub const fn set_crc_test(&mut self, val: bool)

Set to start CRC calculation. This operation will automatically set OTP_STATUS.BUSY. Once CRC is calculation done, OTP_STATUS.BUSY and CRC_TEST are automatically cleared by the controller

pub const fn wordlock(&self) -> bool

Set to write-lock the fuse word when it’s being programming. When programming with ECC mode, it recommends to set this bit.

pub const fn set_wordlock(&mut self, val: bool)

Set to write-lock the fuse word when it’s being programming. When programming with ECC mode, it recommends to set this bit.

pub const fn wr_unlock(&self) -> u16

Write 0x3E77 to enable OTP write accesses. NOTE: The write operation must be unlocked for each word by writing 0x3E77 to WR_UNLOCK field. Then writing to OTP_WRITE_DATA register will automatically start the programming procedure.

pub const fn set_wr_unlock(&mut self, val: u16)

Write 0x3E77 to enable OTP write accesses. NOTE: The write operation must be unlocked for each word by writing 0x3E77 to WR_UNLOCK field. Then writing to OTP_WRITE_DATA register will automatically start the programming procedure.