nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

OtpStatus

Struct OtpStatus 

#[repr(transparent)]
pub struct OtpStatus(pub u32);
Status register

Tuple Fields

0: u32

Implementations

Source

impl OtpStatus

pub const fn sec(&self) -> bool

OTP Single Error Corrected status of ECC during read operation. Write 1 to clear.

pub const fn set_sec(&mut self, val: bool)

OTP Single Error Corrected status of ECC during read operation. Write 1 to clear.

pub const fn ded(&self) -> bool

OTP Double Error Detection status of ECC during read operation. Write 1 to clear.

pub const fn set_ded(&mut self, val: bool)

OTP Double Error Detection status of ECC during read operation. Write 1 to clear.

pub const fn locked(&self) -> bool

OTP LOCKED status during read/write operation. Write 1 to clear.

pub const fn set_locked(&mut self, val: bool)

OTP LOCKED status during read/write operation. Write 1 to clear.

pub const fn progfail(&self) -> bool

OTP PROGFAIL status. Write 1 to clear.

pub const fn set_progfail(&mut self, val: bool)

OTP PROGFAIL status. Write 1 to clear.

pub const fn ack(&self) -> bool

OTP ACK value

pub const fn set_ack(&mut self, val: bool)

OTP ACK value

pub const fn pwok(&self) -> bool

OTP Power OK status. Indicate that power VDD are in the operating range.

pub const fn set_pwok(&mut self, val: bool)

OTP Power OK status. Indicate that power VDD are in the operating range.

pub const fn sec_reload(&self) -> bool

OTP Single Error Corrected status of ECC during reload process. Write 1 to clear.

pub const fn set_sec_reload(&mut self, val: bool)

OTP Single Error Corrected status of ECC during reload process. Write 1 to clear.

pub const fn ded_reload(&self) -> bool

OTP Double Error Detect status of ECC during reload process. Write 1 to clear.

pub const fn set_ded_reload(&mut self, val: bool)

OTP Double Error Detect status of ECC during reload process. Write 1 to clear.

pub const fn busy(&self) -> bool

OTP controller status bit. When active, no new write or read access to OTP (including RELOAD_SHADOWS) can be performed. Cleared by the controller when the access completes. After reset (or after setting RELOAD_SHADOWS), this bit is set by the controller and cleared after all the shadow registers are successfully loaded.

pub const fn set_busy(&mut self, val: bool)

OTP controller status bit. When active, no new write or read access to OTP (including RELOAD_SHADOWS) can be performed. Cleared by the controller when the access completes. After reset (or after setting RELOAD_SHADOWS), this bit is set by the controller and cleared after all the shadow registers are successfully loaded.

pub const fn error(&self) -> bool

Set by the controller when a read/write access to a locked region (OTP or shadow register) is requested. Writing 1 to clear it before any further access can be performed. This bit can only be set by the controller.

pub const fn set_error(&mut self, val: bool)

Set by the controller when a read/write access to a locked region (OTP or shadow register) is requested. Writing 1 to clear it before any further access can be performed. This bit can only be set by the controller.

pub const fn crc_fail(&self) -> bool

CRC failed when set by hardware for CRC operation. Write 1 to clear.

pub const fn set_crc_fail(&mut self, val: bool)

CRC failed when set by hardware for CRC operation. Write 1 to clear.

pub const fn fuse_latched(&self) -> bool

Indicate all shadows registers have been loaded with their corresponding fuse words when set by the controller after reset.

pub const fn set_fuse_latched(&mut self, val: bool)

Indicate all shadows registers have been loaded with their corresponding fuse words when set by the controller after reset.