nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

OtpWriteData

Struct OtpWriteData 

#[repr(transparent)]
pub struct OtpWriteData(pub u32);
OTP programming data register

Tuple Fields

0: u32

Implementations

Source

impl OtpWriteData

pub const fn write_data(&self) -> u32

Fuse word programming data. After the write operation is unlocked in OTP_CTRL register, writing data to this register automatically start the programming procedure.

pub const fn set_write_data(&mut self, val: u32)

Fuse word programming data. After the write operation is unlocked in OTP_CTRL register, writing data to this register automatically start the programming procedure.