#[repr(transparent)]pub struct OtpCtrl(pub u32);Expand description
Control/address register
Tuple Fields
0: u32Implementations
Sourceimpl OtpCtrl
impl OtpCtrl
Sourcepub const fn reload_shadows(&self) -> bool
pub const fn reload_shadows(&self) -> bool
Set to force re-loading the shadow registers (HW/SW capability and LOCK). This operation will automatically set OTP_STATUS.BUSY. Once the shadow registers have been re-loaded, OTP_STATUS.BUSY and RELOAD_SHADOWS are automatically cleared by the controller
Sourcepub const fn set_reload_shadows(&mut self, val: bool)
pub const fn set_reload_shadows(&mut self, val: bool)
Set to force re-loading the shadow registers (HW/SW capability and LOCK). This operation will automatically set OTP_STATUS.BUSY. Once the shadow registers have been re-loaded, OTP_STATUS.BUSY and RELOAD_SHADOWS are automatically cleared by the controller
Sourcepub const fn crc_test(&self) -> bool
pub const fn crc_test(&self) -> bool
Set to start CRC calculation. This operation will automatically set OTP_STATUS.BUSY. Once CRC is calculation done, OTP_STATUS.BUSY and CRC_TEST are automatically cleared by the controller
Sourcepub const fn set_crc_test(&mut self, val: bool)
pub const fn set_crc_test(&mut self, val: bool)
Set to start CRC calculation. This operation will automatically set OTP_STATUS.BUSY. Once CRC is calculation done, OTP_STATUS.BUSY and CRC_TEST are automatically cleared by the controller
Sourcepub const fn wordlock(&self) -> bool
pub const fn wordlock(&self) -> bool
Set to write-lock the fuse word when it’s being programming. When programming with ECC mode, it recommends to set this bit.
Sourcepub const fn set_wordlock(&mut self, val: bool)
pub const fn set_wordlock(&mut self, val: bool)
Set to write-lock the fuse word when it’s being programming. When programming with ECC mode, it recommends to set this bit.
Sourcepub const fn wr_unlock(&self) -> u16
pub const fn wr_unlock(&self) -> u16
Write 0x3E77 to enable OTP write accesses. NOTE: The write operation must be unlocked for each word by writing 0x3E77 to WR_UNLOCK field. Then writing to OTP_WRITE_DATA register will automatically start the programming procedure.
Sourcepub const fn set_wr_unlock(&mut self, val: u16)
pub const fn set_wr_unlock(&mut self, val: u16)
Write 0x3E77 to enable OTP write accesses. NOTE: The write operation must be unlocked for each word by writing 0x3E77 to WR_UNLOCK field. Then writing to OTP_WRITE_DATA register will automatically start the programming procedure.