#[repr(transparent)]pub struct OtpPdn(pub u32);Expand description
Power-down register
Tuple Fields
0: u32Implementations
Sourceimpl OtpPdn
impl OtpPdn
Sourcepub const fn pdn(&self) -> bool
pub const fn pdn(&self) -> bool
This bit indicates the PDN value of OTP memory. Writing 1 to the bit to clear PDN. Writing 0 has no effect. Note: Software need to write 1 to this bit to shut off power of OTP memory after system power up. At the beginning of every fuse operation, the controller will automatically turn-on power to the OPT memory. After every fuse operation, software also need to write 1 to this bit to shut off power to the OTP memory to reduce power consumption.
Sourcepub const fn set_pdn(&mut self, val: bool)
pub const fn set_pdn(&mut self, val: bool)
This bit indicates the PDN value of OTP memory. Writing 1 to the bit to clear PDN. Writing 0 has no effect. Note: Software need to write 1 to this bit to shut off power of OTP memory after system power up. At the beginning of every fuse operation, the controller will automatically turn-on power to the OPT memory. After every fuse operation, software also need to write 1 to this bit to shut off power to the OTP memory to reduce power consumption.