#[repr(transparent)]pub struct OtpStatus(pub u32);Expand description
Status register
Tuple Fields
0: u32Implementations
Sourceimpl OtpStatus
impl OtpStatus
Sourcepub const fn sec(&self) -> bool
pub const fn sec(&self) -> bool
OTP Single Error Corrected status of ECC during read operation. Write 1 to clear.
Sourcepub const fn set_sec(&mut self, val: bool)
pub const fn set_sec(&mut self, val: bool)
OTP Single Error Corrected status of ECC during read operation. Write 1 to clear.
Sourcepub const fn ded(&self) -> bool
pub const fn ded(&self) -> bool
OTP Double Error Detection status of ECC during read operation. Write 1 to clear.
Sourcepub const fn set_ded(&mut self, val: bool)
pub const fn set_ded(&mut self, val: bool)
OTP Double Error Detection status of ECC during read operation. Write 1 to clear.
Sourcepub const fn locked(&self) -> bool
pub const fn locked(&self) -> bool
OTP LOCKED status during read/write operation. Write 1 to clear.
Sourcepub const fn set_locked(&mut self, val: bool)
pub const fn set_locked(&mut self, val: bool)
OTP LOCKED status during read/write operation. Write 1 to clear.
Sourcepub const fn set_progfail(&mut self, val: bool)
pub const fn set_progfail(&mut self, val: bool)
OTP PROGFAIL status. Write 1 to clear.
Sourcepub const fn pwok(&self) -> bool
pub const fn pwok(&self) -> bool
OTP Power OK status. Indicate that power VDD are in the operating range.
Sourcepub const fn set_pwok(&mut self, val: bool)
pub const fn set_pwok(&mut self, val: bool)
OTP Power OK status. Indicate that power VDD are in the operating range.
Sourcepub const fn sec_reload(&self) -> bool
pub const fn sec_reload(&self) -> bool
OTP Single Error Corrected status of ECC during reload process. Write 1 to clear.
Sourcepub const fn set_sec_reload(&mut self, val: bool)
pub const fn set_sec_reload(&mut self, val: bool)
OTP Single Error Corrected status of ECC during reload process. Write 1 to clear.
Sourcepub const fn ded_reload(&self) -> bool
pub const fn ded_reload(&self) -> bool
OTP Double Error Detect status of ECC during reload process. Write 1 to clear.
Sourcepub const fn set_ded_reload(&mut self, val: bool)
pub const fn set_ded_reload(&mut self, val: bool)
OTP Double Error Detect status of ECC during reload process. Write 1 to clear.
Sourcepub const fn busy(&self) -> bool
pub const fn busy(&self) -> bool
OTP controller status bit. When active, no new write or read access to OTP (including RELOAD_SHADOWS) can be performed. Cleared by the controller when the access completes. After reset (or after setting RELOAD_SHADOWS), this bit is set by the controller and cleared after all the shadow registers are successfully loaded.
Sourcepub const fn set_busy(&mut self, val: bool)
pub const fn set_busy(&mut self, val: bool)
OTP controller status bit. When active, no new write or read access to OTP (including RELOAD_SHADOWS) can be performed. Cleared by the controller when the access completes. After reset (or after setting RELOAD_SHADOWS), this bit is set by the controller and cleared after all the shadow registers are successfully loaded.
Sourcepub const fn error(&self) -> bool
pub const fn error(&self) -> bool
Set by the controller when a read/write access to a locked region (OTP or shadow register) is requested. Writing 1 to clear it before any further access can be performed. This bit can only be set by the controller.
Sourcepub const fn set_error(&mut self, val: bool)
pub const fn set_error(&mut self, val: bool)
Set by the controller when a read/write access to a locked region (OTP or shadow register) is requested. Writing 1 to clear it before any further access can be performed. This bit can only be set by the controller.
Sourcepub const fn crc_fail(&self) -> bool
pub const fn crc_fail(&self) -> bool
CRC failed when set by hardware for CRC operation. Write 1 to clear.
Sourcepub const fn set_crc_fail(&mut self, val: bool)
pub const fn set_crc_fail(&mut self, val: bool)
CRC failed when set by hardware for CRC operation. Write 1 to clear.
Sourcepub const fn fuse_latched(&self) -> bool
pub const fn fuse_latched(&self) -> bool
Indicate all shadows registers have been loaded with their corresponding fuse words when set by the controller after reset.
Sourcepub const fn set_fuse_latched(&mut self, val: bool)
pub const fn set_fuse_latched(&mut self, val: bool)
Indicate all shadows registers have been loaded with their corresponding fuse words when set by the controller after reset.